validate_args

Function validate_args 

pub fn validate_args(
    signal: SignalType,
    args: &[u8],
) -> Result<(), &'static str>
Validates the args bytes for the given signal type.

Returns Ok(()) if the args conform to the schema, or an error string describing the first violation. The error string is used by the caller to populate ERR_GSP_BAD_SCHEMA.